package com.css.simulation.resource.common.controller;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.param.RedisParameter;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.time.Duration;


/**
 * https://blog.csdn.net/lzb348110175/article/details/105349109/
 */
@RestController
@RequestMapping("/redis")
public class RedisController {

    @Resource
    RedisTemplate<String, String> redisTemplate;

    @PostMapping("/get")
    public ResponseBodyVO<String> get(@RequestBody @Validated RedisParameter redisParameter) {
        //1 获取 key 对应的值
        String value = redisTemplate.opsForValue().get(redisParameter.getKey());

        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, "请求成功！", value);
    }

    @PostMapping("/set")
    public ResponseBodyVO<String> set(@RequestBody @Validated RedisParameter redisParameter) {
        //2 存储键值对并设置时间。
        redisTemplate.opsForValue().set(redisParameter.getKey(), redisParameter.getValue(), Duration.ofMinutes(redisParameter.getMinutes()));
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

    @PostMapping("/getExpire")
    public ResponseBodyVO<Long> getExpire(@RequestBody @Validated RedisParameter redisParameter) {
        //3 获取指定 key 的剩余时间，单位秒。
        Long time3 = redisTemplate.getExpire(redisParameter.getKey());
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, time3);
    }


    @PostMapping("/delete")
    public ResponseBodyVO<String> delete(@RequestBody @Validated RedisParameter redisParameter) {
        //4 根据 key 删除
        redisTemplate.delete(redisParameter.getKey());
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS);
    }

}